# pcu_io (IO management for PCU project)

IO management for PCU project.
From the path of a file (PDF or JSON), parse it in order to get its textual content.

----

[Check PCU project][pcu].

[pcu]: https://github.com/zevio/pcu_chain
